--------------------
crystal-small
--------------------

This library bundles `Everaldo's Crystal icons
<http://www.everaldo.com/crystal/>`_ for direct consumption with applications.
This is based on `ambv/django-crystal-small <https://github.com/ambv/django-crystal-small>`_
with Django dependencies removed. Sizes available are 16x16, 22x22, 24x24, 32x32 and 48x48.
Look for `django-crystal-big <http://pypi.python.org/pypi/django-crystal-big/>`_ for
64x64 and 128x128. The icons are additionally crushed using pngcrush, optipng
and advpng.

Very simple installation:

The latest version can be installed via `PyPI
<http://pypi.python.org/pypi/crystal-small/>`_::

  $ pip install crystal-small

The `source code repository <http://github.com/mds-dwa/crystal-small>`_
and `issue tracker <http://github.com/mds-dwa/crystal-small/issues>`_
are maintained on `GitHub <http://github.com/mds-dwa/crystal-small>`_.

**Note:** This is only a handy bundle of icons originally
crafted by `Everaldo Coelho <http://www.everaldo.com/about/>`_ and contributors.
These icons have been released under the LGPL, and so is this bundle.
